@@ -1,15 +1,4 @@
 #pragma once
-/**
- *  @file raii_environment.h
- *  @date 13.03.2014
- *  @author mkoenig
- *  @brief 
- *
- *  $LastChangedDate: 2014-11-28 11:59:59 +0100 (Fr, 28 Nov 2014) $
- *  $LastChangedBy: mkoenig $
- *  $LastChangedRevision: 21206 $
- *
- */
 
 #include "cpp_odbc/environment.h"
 
@@ -21,7 +10,7 @@ namespace cpp_odbc {
 
 namespace cpp_odbc { namespace level2 {
 	class api;
-	class environment_handle;
+	struct environment_handle;
 } }
 
 namespace cpp_odbc { namespace level3 {
@@ -53,8 +42,8 @@ public:
 	virtual ~raii_environment();
 
 private:
-	std::shared_ptr<connection const> do_make_connection(std::string const & connection_string) const final;
-	void do_set_attribute(SQLINTEGER attribute, long value) const final;
+	std::shared_ptr<connection> do_make_connection(std::string const & connection_string) const final;
+	void do_set_attribute(SQLINTEGER attribute, intptr_t value) const final;
 
 	struct intern;
 	std::unique_ptr<intern> impl_;
