@@ -5,10 +5,11 @@
 namespace turbodbc {
 
 /**
- * @brief Represents a description to bind a buffer holding integer values
+ * @brief Represents a description to bind a buffer holding string values
  */
 class string_description : public description {
 public:
+	const static int max_code_units_per_unicode_code_point = 4;
 	string_description(std::size_t maximum_length);
 	string_description(std::string name, bool supports_null, std::size_t maximum_length);
 	~string_description();
@@ -16,7 +17,7 @@ private:
 	std::size_t do_element_size() const final;
 	SQLSMALLINT do_column_c_type() const final;
 	SQLSMALLINT do_column_sql_type() const final;
-	void do_set_field(cpp_odbc::writable_buffer_element & element, field const & value) const final;
+	SQLSMALLINT do_digits() const final;
 	type_code do_get_type_code() const final;
 
 	std::size_t maximum_length_;
