@@ -3,6 +3,9 @@
 #include <turbodbc/field.h>
 #include <turbodbc/type_code.h>
 #include <cpp_odbc/multi_value_buffer.h>
+#ifdef _WIN32
+#include <windows.h>
+#endif
 #include <sqltypes.h>
 
 namespace turbodbc {
@@ -17,11 +20,6 @@ public:
 	 */
 	nullable_field make_field(cpp_odbc::buffer_element const & element) const;
 
-	/**
-	 * @brief Set a buffer element to the value of a field
-	 */
-	void set_field(cpp_odbc::writable_buffer_element & element, nullable_field const & value) const;
-
 	field_translator (field_translator const &) = delete;
 	field_translator & operator=(field_translator const &) = delete;
 
@@ -30,7 +28,6 @@ protected:
 	field_translator();
 private:
 	virtual field do_make_field(char const * data_pointer) const = 0;
-	virtual void do_set_field(cpp_odbc::writable_buffer_element & element, field const & value) const = 0;
 };
 
 }
