@@ -22,17 +22,23 @@ public:
 	parameter(cpp_odbc::statement const & statement, std::size_t one_based_index, std::size_t buffered_rows, std::unique_ptr<description const> description);
 
 	/**
-	 * @brief Set the value of the parameter associated with the given row to the given value
-	 * @param row_index Index of the row for which the value is set
-	 * @param value The value which is set
+	 * @brief Return the parameter's type code
 	 */
-	void set(std::size_t row_index, turbodbc::nullable_field const & value);
+	type_code get_type_code() const;
 
 	/**
-	 * @brief Copy the value set for the given row_index to the first row (with index 0)
-	 * @param row_index Index of the row whose value is copied
+	 * @brief Determine whether this parameter is suitable to hold a value of
+	 *        given type and size
+	 * @param code The type code for the value
+	 * @param value_size The size of the value in bytes
+	 * @return True if the parameter could hold such a value, else false.
 	 */
-	void copy_to_first_row(std::size_t row_index);
+	bool is_suitable_for(type_code code, std::size_t value_size) const;
+
+	/**
+	 * @brief Retrieve a reference to the internal buffer
+	*/
+	cpp_odbc::multi_value_buffer & get_buffer();
 
 	~parameter();
 private:
@@ -41,4 +47,12 @@ private:
 };
 
 
+/**
+ * @brief Move the buffer element contained in the given row_index to the first row (with index 0)
+ * @param param Parameter for which to perform the operation
+ * @param row_index Index of the row whose value is copied
+ */
+void move_to_top(parameter & param, std::size_t row_index);
+
+
 }
