@@ -11,6 +11,9 @@
  */
 
 #include "cpp_odbc/level2/handles.h"
+#ifdef _WIN32
+#include <windows.h>
+#endif
 #include "sql.h"
 
 namespace cpp_odbc { namespace level2 {
