@@ -30,10 +30,9 @@ SQLSMALLINT boolean_description::do_column_sql_type() const
 	return SQL_BIT;
 }
 
-void boolean_description::do_set_field(cpp_odbc::writable_buffer_element & element, field const & value) const
+SQLSMALLINT boolean_description::do_digits() const
 {
-	*element.data_pointer = boost::get<bool>(value) ? 1 : 0;
-	element.indicator = 1;
+	return 0;
 }
 
 type_code boolean_description::do_get_type_code() const
@@ -41,4 +40,6 @@ type_code boolean_description::do_get_type_code() const
 	return type_code::boolean;
 }
 
+
+
 }
