@@ -18,7 +18,7 @@ integer_description::~integer_description() = default;
 
 std::size_t integer_description::do_element_size() const
 {
-	return sizeof(long);
+	return sizeof(int64_t);
 }
 
 SQLSMALLINT integer_description::do_column_c_type() const
@@ -31,11 +31,9 @@ SQLSMALLINT integer_description::do_column_sql_type() const
 	return SQL_BIGINT;
 }
 
-void integer_description::do_set_field(cpp_odbc::writable_buffer_element & element, field const & value) const
+SQLSMALLINT integer_description::do_digits() const
 {
-	auto const as_long = boost::get<long>(value);
-	memcpy(element.data_pointer, &as_long, element_size());
-	element.indicator = element_size();
+	return 0;
 }
 
 type_code integer_description::do_get_type_code() const
