@@ -14,10 +14,4 @@ field boolean_translator::do_make_field(char const * data_pointer) const
 	return {static_cast<bool>(*data_pointer)};
 }
 
-void boolean_translator::do_set_field(cpp_odbc::writable_buffer_element & element, field const & value) const
-{
-	*element.data_pointer = boost::get<bool>(value) ? 1 : 0;
-	element.indicator = 1;
-}
-
 } }
