@@ -14,10 +14,4 @@ field float64_translator::do_make_field(char const * data_pointer) const
 	return {*reinterpret_cast<double const *>(data_pointer)};
 }
 
-void float64_translator::do_set_field(cpp_odbc::writable_buffer_element & element, field const & value) const
-{
-	*reinterpret_cast<double *>(element.data_pointer) = boost::get<double>(value);
-	element.indicator = sizeof(double);
-}
-
 } }
