@@ -11,13 +11,7 @@ int64_translator::~int64_translator() = default;
 
 field int64_translator::do_make_field(char const * data_pointer) const
 {
-	return {*reinterpret_cast<long const *>(data_pointer)};
-}
-
-void int64_translator::do_set_field(cpp_odbc::writable_buffer_element & element, field const & value) const
-{
-	*reinterpret_cast<long *>(element.data_pointer) = boost::get<long>(value);
-	element.indicator = sizeof(long);
+	return {*reinterpret_cast<int64_t const *>(data_pointer)};
 }
 
 } }
