@@ -4,4 +4,4 @@ https://www.python.org/dev/peps/pep-0249/#globals
 """
 apilevel = "2.0"
 threadsafety = 1
-paramstyle = 'qmark'
\ No newline at end of file
+paramstyle = "qmark"
